# eric7.Plugins.WizardPlugins.QRegularExpressionWizard.QRegularExpressionWizardServer

Module implementing the PyQt6 server part of the QRegularExpression wizzard.

### Global Attributes

None

### Classes

None

### Functions

main | Function containing the main routine.
rxExecute | Function to execute the given regular expression for a given text.
rxValidate | Function to validate the given regular expression.

## main

main()

Function containing the main routine.

Up

## rxExecute

rxExecute(regexp, options, text, startpos)

Function to execute the given regular expression for a given text.

regexp (str)
  regular expression to validate
options (list of str)
  list of options
text (str)
  text to execute on
startpos (int)
  start position for the execution

Return:
  tuple of a flag indicating a successful match and a list of captures containing the complete match as matched string, match start, match end and match length for each entry

Return Type:
  tuple of (bool, list of [str, int, int, int])

Up

## rxValidate

rxValidate(regexp, options)

Function to validate the given regular expression.

regexp (str)
  regular expression to validate
options (list of str)
  list of options

Return:
  tuple of flag indicating validity, error string and error offset

Return Type:
  tuple of (bool, str, int)

Up